<?php

namespace Ss\Ss\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Ss\Ss\Interfaces\CommentsRepositoryInterface;
use Ss\Ss\Repositories\Presenter\CommentsItemTransformer;

/**
 * Pubic API controller class.
 */
class CommentsPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Ss\Comments\Interfaces\CommentsRepositoryInterface $comments
     *
     * @return type
     */
    public function __construct(CommentsRepositoryInterface $comments)
    {
        $this->repository = $comments;
        parent::__construct();
    }

    /**
     * Show comments's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $comments = $this->repository
            ->setPresenter('\\Ss\\Ss\\Repositories\\Presenter\\CommentsListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $comments['code'] = 2000;
        return response()->json($comments)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show comments.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $comments = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($comments)) {
            $comments         = $this->itemPresenter($module, new CommentsItemTransformer);
            $comments['code'] = 2001;
            return response()->json($comments)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
