<?php

namespace Ss\Ss\Http\Controllers;
use Litepie\Ss\Http\Requests\CommentsRequest;
use Litepie\Ss\Models\Comments;

trait CommentsWorkflow {
	
    /**
     * Workflow controller function for comments.
     *
     * @param Model   $comments
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CommentsRequest $request, Comments $comments, $step)
    {

        try {

            $comments->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('ss::comments.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/comments/comments/' . $comments->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/comments/comments/' . $comments->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for comments.
     *
     * @param Model   $comments
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Comments $comments, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $comments->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('ss::comments.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('ss::admin.comments.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('ss::admin.comments.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('ss::admin.comments.message', $data)->render();

        }

    }
}