<?php

namespace Ss\Ss\Policies;

use App\User;
use Ss\Ss\Models\Comments;

class CommentsPolicy
{

    /**
     * Determine if the given user can view the comments.
     *
     * @param User $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function view(User $user, Comments $comments)
    {
        if ($user->canDo('ss.comments.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $comments->user_id;
    }

    /**
     * Determine if the given user can create a comments.
     *
     * @param User $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('ss.comments.create');
    }

    /**
     * Determine if the given user can update the given comments.
     *
     * @param User $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function update(User $user, Comments $comments)
    {
        if ($user->canDo('ss.comments.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $comments->user_id;
    }

    /**
     * Determine if the given user can delete the given comments.
     *
     * @param User $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function destroy(User $user, Comments $comments)
    {
        if ($user->canDo('ss.comments.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $comments->user_id;
    }

    /**
     * Determine if the given user can verify the given comments.
     *
     * @param User $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function verify(User $user, Comments $comments)
    {
        if ($user->canDo('ss.comments.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('ss.comments.verify') 
        && $user->is('manager')
        && $comments->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given comments.
     *
     * @param User $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function approve(User $user, Comments $comments)
    {
        if ($user->canDo('ss.comments.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
