<?php

namespace Ss\Ss\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Ss\Ss\Models\Comments;

class CommentsAction
{
    /**
     * Perform the complete action.
     *
     * @param Comments $comments
     *
     * @return Comments
     */
    public function complete(Comments $comments)
    {
        try {
            $comments->status = 'complete';
            return $comments->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Comments $comments
     *
     * @return Comments
     */public function verify(Comments $comments)
    {
        try {
            $comments->status = 'verify';
            return $comments->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Comments $comments
     *
     * @return Comments
     */public function approve(Comments $comments)
    {
        try {
            $comments->status = 'approve';
            return $comments->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Comments $comments
     *
     * @return Comments
     */public function publish(Comments $comments)
    {
        try {
            $comments->status = 'publish';
            return $comments->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Comments $comments
     *
     * @return Comments
     */
    public function archive(Comments $comments)
    {
        try {
            $comments->status = 'archive';
            return $comments->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Comments $comments
     *
     * @return Comments
     */
    public function unpublish(Comments $comments)
    {
        try {
            $comments->status = 'unpublish';
            return $comments->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
