<?php

namespace Ss\Ss\Workflow;

use Ss\Ss\Models\Comments;
use Validator;

class CommentsValidator
{

    /**
     * Determine if the given comments is valid for complete status.
     *
     * @param Comments $comments
     *
     * @return bool / Validator
     */
    public function complete(Comments $comments)
    {
        return Validator::make($comments->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given comments is valid for verify status.
     *
     * @param Comments $comments
     *
     * @return bool / Validator
     */
    public function verify(Comments $comments)
    {
        return Validator::make($comments->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given comments is valid for approve status.
     *
     * @param Comments $comments
     *
     * @return bool / Validator
     */
    public function approve(Comments $comments)
    {
        return Validator::make($comments->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given comments is valid for publish status.
     *
     * @param Comments $comments
     *
     * @return bool / Validator
     */
    public function publish(Comments $comments)
    {
        return Validator::make($comments->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given comments is valid for archive status.
     *
     * @param Comments $comments
     *
     * @return bool / Validator
     */
    public function archive(Comments $comments)
    {
        return Validator::make($comments->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given comments is valid for unpublish status.
     *
     * @param Comments $comments
     *
     * @return bool / Validator
     */
    public function unpublish(Comments $comments)
    {
        return Validator::make($comments->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
